"""Cataloging components for WAeUP SIRP access-codes.
"""
import grok
from datetime import datetime
from hurry.query import Between
from waeup.sirp.interfaces import IUniversity
from waeup.sirp.accesscodes.interfaces import IAccessCode

ac_cat_name = ('accesscode_catalog', 'name')
ac_cat_invalidated = ('accesscode_catalog', 'invalidated')

class AccessCodeCatalog(grok.Indexes):
     """The accesscode catalog.
     """
     grok.site(IUniversity)
     grok.name('accesscode_catalog')
     grok.context(IAccessCode)

     # We want to search for ACs by text and as attributes.
     text = grok.index.Text(attribute='representation')
     name = grok.index.Field(attribute='representation')
     invalidated = grok.index.Field(attribute='invalidation_date')
     student_id = grok.index.Field(attribute='student_id')

def search_invalidated(batch_prefix, batch_num):
     """Get set of ACs in batch already invalidated.
     """
     start = '%s-%s-' % (batch_prefix, batch_num)
     end = '%s-%s-9999999999' % (batch_prefix, batch_num)
     query = Between(
          ac_cat_invalidated, datetime(1, 1, 1), None) & Between(
          ac_cat_name, start, end)
     return query.apply()

def invalidated_num(batch_prefix, batch_num):
     """Get number of invalidated entries in batch.
     """
     return len(search_invalidated(batch_prefix, batch_num))
